.. _spkg_execnet:

execnet: Rapid multi-Python deployment
================================================

Description
-----------

Rapid multi-Python deployment

License
-------

Upstream Contact
----------------

https://pypi.org/project/execnet/


Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.1.1

version_requirements.txt::

    execnet


Equivalent System Packages
--------------------------

(none known)

